@@ -1,4 +1,4 @@
-# $Id: Coverage.pm 20433 2006-05-19 13:42:08Z wsnyder $
+# $Id: Coverage.pm 22733 2006-07-11 13:37:09Z wsnyder $
 ######################################################################
 #
 # Copyright 2001-2006 by Wilson Snyder.  This program is free software;
@@ -29,7 +29,7 @@ use vars qw($_Default_Self);
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.261';
+$VERSION = '1.270';
 
 use constant DEFAULT_FILENAME => 'logs/coverage.pl';
 
@@ -254,15 +254,25 @@ back by simply evaluating the file.
 
 =back
 
-=head1 SEE ALSO
+=head1 DISTRIBUTION
 
-vcoverage,
-SystemC::Coverage::Item
+SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+tool suite.  The latest version is available from CPAN and from
+L<http://www.veripool.com/systemperl.html>.
+
+Copyright 2001-2006 by Wilson Snyder.  This package is free software; you
+can redistribute it and/or modify it under the terms of either the GNU
+Lesser General Public License or the Perl Artistic License.
 
 =head1 AUTHORS
 
 Wilson Snyder <wsnyder@wsnyder.org>
 
+=head1 SEE ALSO
+
+vcoverage,
+SystemC::Coverage::Item
+
 =cut
 
 ######################################################################
