@@ -1,4 +1,4 @@
-#$Id: Parser.pm 20433 2006-05-19 13:42:08Z wsnyder $
+#$Id: Parser.pm 22733 2006-07-11 13:37:09Z wsnyder $
 ######################################################################
 #
 # Copyright 2001-2006 by Wilson Snyder.  This program is free software;
@@ -21,7 +21,7 @@ require DynaLoader;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.261';
+$VERSION = '1.270';
 
 ######################################################################
 #### Configuration Section
@@ -225,7 +225,9 @@ stripped // Auto inserted comments.
 
 =head1 DISTRIBUTION
 
-The latest version is available from CPAN and from L<http://www.veripool.com/>.
+SystemPerl is part of the L<http://www.veripool.com/> free SystemC software
+tool suite.  The latest version is available from CPAN and from
+L<http://www.veripool.com/systemperl.html>.
 
 Copyright 2001-2006 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
